Cirun's Python Client documentation!
====================================

Cirun's API can be accessed via this client.

Installation
============

.. code-block:: bash

    pip install cirun


or via `conda-forge`

.. code-block:: bash

    conda install -c conda-forge cirun


.. toctree::
   :maxdepth: 2

   api

Contributing
============

There are multiple ways you can contibute to cirun client

* Add missing documentation.
* Report bugs.

Use github's Pull request/issues feature for all contributions.
